# This is a short term solution until Intel puts their source repository back up at http://meego.gitorious.org/
# wget http://mirrors3.kernel.org/meego/releases/1.1/netbook/repos/source/mutter-2.31.5_1.1-1.10.src.rpm
# rpm -i mutter-2.31.5_1.0-1.1.src.rpm
%define tarfile mutter-2.31.5_1.1.tar.bz2

Name:          mutter-mbl
Version:       2.31.5_1.1
Release:       4%{?dist}
Summary:       Window and compositing manager based on Clutter

Group:         User Interface/Desktops
License:       GPLv2+
URL:           http://www.meego.com/
Source0:       %{tarfile}
Patch0:        mutter-notused.patch

BuildRequires: clutter-devel
BuildRequires: pango-devel
BuildRequires: startup-notification-devel
BuildRequires: gtk2-devel
BuildRequires: pkgconfig
BuildRequires: GConf2-devel
BuildRequires: gobject-introspection-devel
BuildRequires: libSM-devel
BuildRequires: libX11-devel
BuildRequires: libXdamage-devel
BuildRequires: libXext-devel
BuildRequires: libXrandr-devel
BuildRequires: libXrender-devel
BuildRequires: libXcursor-devel
BuildRequires: libXcomposite-devel
BuildRequires: zenity
BuildRequires: intltool
BuildRequires: gnome-doc-utils
BuildRequires: desktop-file-utils

#Temp while we're using git master
BuildRequires: libtool
BuildRequires: gnome-common

Requires: control-center-filesystem
Requires: startup-notification
Requires: GConf2
Requires: dbus-x11
Requires: zenity

# Initally we need to conflict with mutter. A patch is in progress so that they'll both be parallel installable
Conflicts: mutter

%description
Mutter-mbl is a fork of the mutter window and compositing manager that 
displays and manages your desktop via OpenGL. Mutter combines a 
sophisticated display engine using the Clutter toolkit with solid 
window-management logic inherited from the Metacity window manager.

%package devel
Summary: Development package for %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig
# Initally we need to conflict with mutter. A patch is in progress so that they'll both be parallel installable
Conflicts: mutter-devel

%description devel
Header files and libraries for developing Mutter plugins. Also includes
utilities for testing Metacity/Mutter themes.

%prep
%setup -q -n mutter-%{version}
%patch0 -p1 -b .notused

# Remove exec perms from source files
chmod -x src/compositor/*.c

%build
%configure --with-clutter --disable-static

# Remove rpath as per https://fedoraproject.org/wiki/Packaging/Guidelines#Beware_of_Rpath
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

SHOULD_HAVE_DEFINED="HAVE_SM HAVE_XINERAMA HAVE_XFREE_XINERAMA HAVE_SHAPE HAVE_RANDR HAVE_STARTUP_NOTIFICATION HAVE_COMPOSITE_EXTENSION"

for I in $SHOULD_HAVE_DEFINED; do
  if ! grep -q "define $I" config.h; then
    echo "$I was not defined in config.h"
    grep "$I" config.h
    exit 1
  else
    echo "$I was defined as it should have been"
    grep "$I" config.h
  fi
done

make %{?_smp_mflags} V=1

%install
export GCONF_DISABLE_MAKEFILE_SCHEMA_INSTALL=1
make install DESTDIR=%{buildroot}
unset GCONF_DISABLE_MAKEFILE_SCHEMA_INSTALL

#Remove libtool archives.
rm -rf %{buildroot}/%{_libdir}/*.la

%find_lang mutter

# Mutter contains a .desktop file so we just need to validate it
desktop-file-validate %{buildroot}/%{_datadir}/applications/mutter.desktop

%pre 
if [ "$1" -gt 1 ]; then
  export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
  gconftool-2 --makefile-uninstall-rule \
    %{_sysconfdir}/gconf/schemas/mutter.schemas \
    > /dev/null || :
fi

%preun 
if [ "$1" -eq 0 ]; then
  export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
  gconftool-2 --makefile-uninstall-rule \
    %{_sysconfdir}/gconf/schemas/mutter.schemas \
    > /dev/null || :
fi

%post 
/sbin/ldconfig
export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
gconftool-2 --makefile-install-rule \
    %{_sysconfdir}/gconf/schemas/mutter.schemas \
  > /dev/null || :

%postun -p /sbin/ldconfig

%files -f mutter.lang
%defattr(-,root,root,-)
%doc README AUTHORS COPYING NEWS HACKING doc/theme-format.txt
%doc %{_mandir}/man1/mutter.1.gz
%doc %{_mandir}/man1/mutter-message.1.gz
%{_bindir}/mutter
%{_bindir}/mutter-message
%{_datadir}/applications/*.desktop
%{_datadir}/gnome/wm-properties/mutter-wm.desktop
%{_sysconfdir}/gconf/schemas/mutter.schemas
%{_datadir}/mutter
%{_libdir}/lib*.so.*
%{_libdir}/mutter/

%files devel
%defattr(-,root,root,-)
%{_bindir}/mutter-theme-viewer
%{_bindir}/mutter-window-demo
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*
%doc %{_mandir}/man1/mutter-theme-viewer.1.gz
%doc %{_mandir}/man1/mutter-window-demo.1.gz

%changelog
* Thu Oct 13 2011 Peter Robinson <pbrobinson@fedoraproject.org> - 2.31.5_1.1-4
- Fix FTBFS 715855

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.31.5_1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec  6 2010 Peter Robinson <pbrobinson@fedoraproject.org> 2.31.5_1.1-2
- Build against gtk3

* Sun Dec  5 2010 Peter Robinson <pbrobinson@fedoraproject.org> 2.31.5_1.1-1
- Update to 2.31.5_1.1 release

* Wed Sep  1 2010 Peter Robinson <pbrobinson@fedoraproject.org> 2.31.5_1.0-1
- Update to 2.31.5_1.0 release

* Wed Jul 14 2010 Peter Robinson <pbrobinson@fedoraproject.org> 2.29.1_1.0-1
- Update to 2.29.1_1.0 release

* Mon Jul 12 2010 Colin Walters <walters@pocket> - 2.29.1_0.5-2
- Rebuild for new gobject-introspection

* Sun Jul 11 2010 Peter Robinson <pbrobinson@fedoraproject.org> 2.29.1_0.5-1
- Update to 2.29.1_0.5 release

* Fri Jun 25 2010 Peter Robinson <pbrobinson@fedoraproject.org> 2.29.1_0.4-1
- Update to 2.29.1_0.4 release

* Thu Mar 25 2010 Peter Robinson <pbrobinson@fedoraproject.org> 2.28.1_0.12-1
- Update to 2.28.1_0.12 release

* Thu Mar 25 2010 Peter Robinson <pbrobinson@fedoraproject.org> 2.28.1_0.0-1
- Initial spec based on mutter
